==================================
 OpenStack User Committee Charter
==================================

Starting August 1st, 2020, the User Committee will no longer operate as
a separate entity. The entire OpenStack community will be represented by
a single elected body, including developers, operators and end users of
the OpenStack software, and inclusive of all types of contributions to
the project.

To avoid a costly amendment of the Bylaws, that single elected body will
be called "the Technical Committee", but its role will be expanded to
cover duties formerly filled by the User Committee.

Motivation
==========

When the OpenStack project governance was established in 2012, we defined
two separate bodies. The Technical Committee represented developers / code
contributors to the open source project(s), while the User Committee
represented the operators running the resulting software, as well as users
of the APIs.

That setup served us well in those early days. The focus on the upstream
side was strongly around *development* of code, we did not have that many
users, and even less users directly involved in upstream development.
A separate User Committee resulted in the formation of an engaged community
of users, and ensured that our community in general (and our events in
particular) took the needs of operators into account.

We now have a lot of users, and thanks to the efforts of the User Committee
they are increasingly directly involved in the open source project development
and maintenance, with several operators leading upstream project teams
directly.

Keeping two separate bodies maintains the illusion that devs and ops are
different breeds, and that you have to choose a side. Having a unified body
will encourage more operators to contribute directly, to run for election to
the Technical Committee, and to influence the shape of the software.

User Committee
==============

The User Committee is defined in the OpenStack bylaws. To avoid amending the
bylaws, the User Committee will still formally exist, with the following rules.

Membership
----------

The User Committee consists of five members: the Technical Committee chair and
four other members, elected from within the current Technical Committee
membership. Not more than half of the members of the User Committee should be
affiliated with the same organization.

The User Committee will therefore formally be a subcommittee of the Technical
Committee, although the User Committee mission (representing and serving the
user community of OpenStack) will be filled by all the Technical Committee
members.

Chair
-----

The bylaws require a chair of the User Committee to be designated. The chair
of the Technical Committee will fill that role.

The chair of the User Committee is a honorific title, they do not fill any
specific duty.

Active User Contributor
-----------------------

The bylaws define 'Active User Contributors' as being the electorate to elect
the User Committee. Since the Technical Committee members now elect the User
Committee members, starting on August 1st, 2020, Active User Contributors are
the elected Technical Committee members.

The Active User Contibutors electorate (previously used to elect the separate
User Committee body) will be included in the electorate electing the Technical
Committee. To that effect, the Active User Contributor criteria will be used
by the Foundation to propose such contributors as extra Active Technical
Contributors if they are not part of the Technical Committee electorate
already.

Meetings
--------

The User Committee is considered meeting every time the Technical Committee
meets and at least three of the User Committee members are present.

Amendments to this charter
--------------------------

This charter may be amended by a simple vote by the Technical Committee
members.
